# "example\_lib" directory

The contents of this directory are not a part of core-"bobbin".  The modules in
this directory are just for making some training scripts in "example" simpler,
and are more relevant to be serapated out as libraries.  Therefore, no one
should rely on the presence of those modules in this directory.
